@@ -357,26 +357,28 @@ class MatterClient:
             thread_cluster: Clusters.ThreadNetworkDiagnostics = node.get_cluster(
                 0, Clusters.ThreadNetworkDiagnostics
             )
-            if isinstance(thread_cluster.networkName, bytes):
-                network_name = thread_cluster.networkName.decode("utf-8")
-            elif thread_cluster.networkName != NullValue:
-                network_name = thread_cluster.networkName
-            # parse routing role to (diagnostics) node type
-            if (
-                thread_cluster.routingRole
-                == Clusters.ThreadNetworkDiagnostics.Enums.RoutingRoleEnum.kSleepyEndDevice
-            ):
-                node_type = NodeType.SLEEPY_END_DEVICE
-            if thread_cluster.routingRole in (
-                Clusters.ThreadNetworkDiagnostics.Enums.RoutingRoleEnum.kLeader,
-                Clusters.ThreadNetworkDiagnostics.Enums.RoutingRoleEnum.kRouter,
-            ):
-                node_type = NodeType.ROUTING_END_DEVICE
-            elif (
-                thread_cluster.routingRole
-                == Clusters.ThreadNetworkDiagnostics.Enums.RoutingRoleEnum.kEndDevice
-            ):
-                node_type = NodeType.END_DEVICE
+            if thread_cluster:
+                if isinstance(thread_cluster.networkName, bytes):
+                    network_name = thread_cluster.networkName.decode(
+                        "utf-8", errors="replace"
+                    )
+                elif thread_cluster.networkName != NullValue:
+                    network_name = thread_cluster.networkName
+
+                # parse routing role to (diagnostics) node type
+                RoutingRole = Clusters.ThreadNetworkDiagnostics.Enums.RoutingRoleEnum  # noqa: N806
+                if thread_cluster.routingRole == RoutingRole.kSleepyEndDevice:
+                    node_type = NodeType.SLEEPY_END_DEVICE
+                elif thread_cluster.routingRole in (
+                    RoutingRole.kLeader,
+                    RoutingRole.kRouter,
+                ):
+                    node_type = NodeType.ROUTING_END_DEVICE
+                elif thread_cluster.routingRole in (
+                    RoutingRole.kEndDevice,
+                    RoutingRole.kReed,
+                ):
+                    node_type = NodeType.END_DEVICE
         elif network_type == NetworkType.WIFI:
             node_type = NodeType.END_DEVICE
         # use lastNetworkID from NetworkCommissioning cluster as fallback to get the network name
@@ -390,7 +392,7 @@ class MatterClient:
             )
         ):
             if isinstance(last_network_id, bytes):
-                network_name = last_network_id.decode("utf-8")
+                network_name = last_network_id.decode("utf-8", errors="replace")
             elif last_network_id != NullValue:
                 network_name = last_network_id
         # last resort to get the (wifi) networkname;
@@ -407,7 +409,7 @@ class MatterClient:
                 if not network.connected:
                     continue
                 if isinstance(network.networkID, bytes):
-                    network_name = network.networkID.decode("utf-8")
+                    network_name = network.networkID.decode("utf-8", errors="replace")
                     break
                 if network.networkID != NullValue:
                     network_name = network.networkID
@@ -463,18 +465,15 @@ class MatterClient:
     async def read_attribute(
         self,
         node_id: int,
-        attribute_path: str,
+        attribute_path: str | list[str],
     ) -> dict[str, Any]:
         """Read one or more attribute(s) on a node by specifying an attributepath."""
         updated_values = await self.send_command(
             APICommand.READ_ATTRIBUTE,
-            require_schema=4,
+            require_schema=9,
             node_id=node_id,
             attribute_path=attribute_path,
         )
-        if not isinstance(updated_values, dict):
-            # can happen is the server is running schema < 8
-            return {attribute_path: updated_values}
         return cast(dict[str, Any], updated_values)
 
     async def refresh_attribute(
@@ -510,23 +509,6 @@ class MatterClient:
         """Interview a node."""
         await self.send_command(APICommand.INTERVIEW_NODE, node_id=node_id)
 
-    async def subscribe_attribute(
-        self, node_id: int, attribute_path: str | list[str]
-    ) -> None:
-        """
-        Subscribe to given AttributePath(s).
-
-        Either supply a single attribute path or a list of paths.
-        The given attribute path(s) will be added to the list of attributes that
-        are watched for the given node. This is persistent over restarts.
-        """
-        await self.send_command(
-            APICommand.SUBSCRIBE_ATTRIBUTE,
-            require_schema=4,
-            node_id=node_id,
-            attribute_path=attribute_path,
-        )
-
     async def send_command(
         self,
         command: str,
